@@ -3,6 +3,8 @@ package Padre::Plugin::Catalyst::Util;
 use Cwd ();
 use File::Spec ();
 
+our $VERSION = '0.02';
+
 # get the Catalyst project name, so we can
 # figure out the development server's name
 # TODO: make this code suck less
@@ -18,6 +20,19 @@ sub get_catalyst_project_name {
     return $project_name;
 }
 
+sub find_file_from_output {
+	my $filename = shift;
+	my $output_text = shift;
+	
+	$filename .= '.pm';
+	
+	if ($output_text =~ m{created "(.+$filename(?:\.new)?)"}) {
+		return $1;
+	}
+	else {
+		return; # sorry, not found
+	}
+}
 
 sub get_document_base_dir {	
 	my $main = Padre->ide->wx->main;
